@@ -8,11 +8,52 @@ set -o pipefail
 export PYTHONUNBUFFERED=1
 
 function test_smoke {
-    openstack --debug compute service list
-    openstack --debug network agent list
-    openstack --debug orchestration service list
+    attempts=10
+
+    for i in $(seq 1 ${attempts}); do
+        if openstack --debug compute service list; then
+            break
+        elif [[ $i -eq ${attempts} ]]; then
+            echo "Failed to list compute services after ${attempts} attempts"
+        else
+            echo "Cannot list compute services, retrying"
+        fi
+        sleep 10
+    done
+
+    for i in $(seq 1 ${attempts}); do
+        if openstack --debug network agent list; then
+            break
+        elif [[ $i -eq ${attempts} ]]; then
+            echo "Failed to list network services after ${attempts} attempts"
+        else
+            echo "Cannot list network services, retrying"
+        fi
+        sleep 10
+    done
+
+    for i in $(seq 1 ${attempts}); do
+        if openstack --debug orchestration service list; then
+            break
+        elif [[ $i -eq ${attempts} ]]; then
+            echo "Failed to list orchestration services after ${attempts} attempts"
+        else
+            echo "Cannot list orchestration services, retrying"
+        fi
+        sleep 10
+    done
+
     if [[ $SCENARIO == "cephadm" ]] || [[ $SCENARIO == "zun" ]]; then
-        openstack --debug volume service list
+        for i in $(seq 1 ${attempts}); do
+            if openstack --debug volume service list; then
+                break
+            elif [[ $i -eq ${attempts} ]]; then
+                echo "Failed to list volume services after ${attempts} attempts"
+            else
+                echo "Cannot list volume services, retrying"
+            fi
+            sleep 10
+        done
     fi
 }
 
@@ -159,46 +200,31 @@ function delete_a_volume {
 
 function create_instance {
     local name=$1
-    openstack server create --wait --image cirros --flavor m1.tiny --key-name mykey --network demo-net ${name}
-    # If the status is not ACTIVE, print info and exit 1
-    if [[ $(openstack server show ${name} -f value -c status) != "ACTIVE" ]]; then
-        echo "FAILED: Instance is not active"
-        openstack --debug server show ${name}
-        return 1
-    fi
-}
+    local server_create_extra
 
-function resize_instance {
-    local name=$1
-
-    # TODO(priteau): Remove once previous_release includes m2.tiny in
-    # init-runonce
-    if ! openstack flavor list -f value | grep m2.tiny; then
-        openstack flavor create --id 6 --ram 512 --disk 1 --vcpus 2 m2.tiny
+    if [[ $IP_VERSION -eq 6 ]]; then
+        # NOTE(yoctozepto): CirrOS has no IPv6 metadata support, hence need to use configdrive
+        server_create_extra="${server_create_extra} --config-drive True"
     fi
 
-    openstack server resize --flavor m2.tiny --wait ${name}
-    # If the status is not VERIFY_RESIZE, print info and exit 1
-    if [[ $(openstack server show ${name} -f value -c status) != "VERIFY_RESIZE" ]]; then
-        echo "FAILED: Instance is not resized"
-        openstack --debug server show ${name}
-        return 1
-    fi
-
-    openstack server resize confirm ${name}
-
-    # Confirming the resize operation is not instantaneous. Wait for change to
-    # be reflected in server status.
-    attempt=1
-    while [[ $(openstack server show ${name} -f value -c status) != "ACTIVE" ]]; do
-        echo "Instance is not active yet"
-        attempt=$((attempt+1))
-        if [[ $attempt -eq 5 ]]; then
-            echo "FAILED: Instance failed to become active after resize confirm"
-            openstack --debug server show ${name}
-            return 1
+    attempts=10
+    for i in $(seq 1 ${attempts}); do
+        if openstack server create --wait --image cirros --flavor m1.tiny --key-name mykey --network demo-net ${server_create_extra} ${name}; then
+            # If the status is not ACTIVE, print info and exit 1
+            if [[ $(openstack server show ${name} -f value -c status) != "ACTIVE" ]]; then
+                echo "FAILED: Instance is not active"
+                openstack --debug server show ${name}
+                openstack server delete ${name}
+            else
+                break
+            fi
+        elif [[ $i -eq ${attempts} ]]; then
+            echo "Failed to create instance after ${attempts} attempts"
+        else
+            echo "Cannot create instance, retrying"
+            openstack server delete ${name}
         fi
-        sleep 1
+        sleep 10
     done
 }
 
@@ -349,23 +375,27 @@ function test_instance_boot {
     openstack image delete image_from_instance
     echo "SUCCESS: Instance image upload"
 
-    echo "TESTING: Floating ip allocation"
-    fip_addr=$(create_fip)
-    attach_fip kolla_boot_test ${fip_addr}
-    echo "SUCCESS: Floating ip allocation"
+    if [[ $IP_VERSION -eq 4 ]]; then
+        echo "TESTING: Floating ip allocation"
+        fip_addr=$(create_fip)
+        attach_fip kolla_boot_test ${fip_addr}
+        echo "SUCCESS: Floating ip allocation"
+    else
+        # NOTE(yoctozepto): Neutron has no IPv6 NAT support, hence no floating ip addresses
+        local instance_addresses
+        fip_addr=$(openstack server show kolla_boot_test -f yaml -c addresses|tail -1|cut -d- -f2)
+    fi
 
-    echo "TESTING: PING&SSH to floating ip"
+    echo "TESTING: PING&SSH to instance"
     test_ssh kolla_boot_test ${fip_addr}
-    echo "SUCCESS: PING&SSH to floating ip"
+    echo "SUCCESS: PING&SSH to instance"
 
-    echo "TESTING: Floating ip deallocation"
-    detach_fip kolla_boot_test ${fip_addr}
-    delete_fip ${fip_addr}
-    echo "SUCCESS: Floating ip deallocation"
-
-    echo "TESTING: Server resize"
-    resize_instance kolla_boot_test
-    echo "SUCCESS: Server resize"
+    if [[ $IP_VERSION -eq 4 ]]; then
+        echo "TESTING: Floating ip deallocation"
+        detach_fip kolla_boot_test ${fip_addr}
+        delete_fip ${fip_addr}
+        echo "SUCCESS: Floating ip deallocation"
+    fi
 
     echo "TESTING: Server deletion"
     delete_instance kolla_boot_test
