@@ -9,13 +9,15 @@ function test_zun_logged {
     . /etc/kolla/admin-openrc.sh
     . ~/openstackclient-venv/bin/activate
 
+    container_engine="${1:-docker}"
+
     echo "TESTING: Zun"
     openstack appcontainer service list
     openstack appcontainer host list
     openstack subnet set --no-dhcp demo-subnet
-    sudo docker pull alpine
-    sudo docker save alpine | openstack image create alpine --public --container-format docker --disk-format raw
-    openstack appcontainer run --name test alpine sleep 1000
+    sudo ${container_engine} pull alpine
+    sudo ${container_engine} save alpine | openstack image create alpine --public --container-format docker --disk-format raw
+    openstack appcontainer run --net network=demo-net --name test alpine sleep 1000
     attempt=1
     while [[ $(openstack appcontainer show test -f value -c status) != "Running" ]]; do
         echo "Container not running yet"
@@ -61,7 +63,7 @@ function test_zun_logged {
         fi
         sleep 10
     done
-    openstack appcontainer run --name test2 --mount source=zun_test_volume,destination=/data alpine sleep 1000
+    openstack appcontainer run --net network=demo-net --name test2 --mount source=zun_test_volume,destination=/data alpine sleep 1000
     attempt=1
     while [[ $(openstack volume show zun_test_volume -f value -c status) != "in-use" ]]; do
         echo "Volume not attached yet"
@@ -111,6 +113,12 @@ capsuleVersion: beta
 kind: capsule
 metadata:
   name: capsule-test
+# NOTE(yoctozepto): Capsules do not support nets in Ussuri.
+# See https://bugs.launchpad.net/zun/+bug/1895263
+# The choice for CI is worked around by ensuring the networks are created
+# in the desired order in init-runonce.
+#nets:
+#  - network: demo-net
 spec:
   containers:
   - image: alpine
@@ -154,7 +162,7 @@ function test_zun {
     if [[ -f $log_file ]]; then
         log_file=${log_file}-upgrade
     fi
-    test_zun_logged > $log_file 2>&1
+    test_zun_logged $1 > $log_file 2>&1
     result=$?
     if [[ $result != 0 ]]; then
         echo "Testing Zun failed. See ansible/test-zun for details"
@@ -164,4 +172,4 @@ function test_zun {
     return $result
 }
 
-test_zun
+test_zun $1
